import { LogLevel } from '@genesislcap/foundation-logger';
import { ErrorStructure, ErrorBanner, ErrorDialog, ErrorNotification, Snackbar } from './types';
/**
 * ErrorBuilder to build ErrorStructure
 * @public
 */
export declare class ErrorBuilder {
    private title;
    private errorDetails;
    private logLevel;
    private alert;
    private notification;
    private banner;
    private snackbar;
    private dialog;
    /**
     * Add title to error
     * @public
     * @param title - string
     * @returns
     */
    withTitle(title: string): ErrorBuilder;
    /**
     * Add error details to error
     * @public
     * @param errorDetails - string
     * @returns
     */
    withErrorDetails(errorDetails: string): ErrorBuilder;
    /**
     * Add log level to error
     * @public
     * @returns
     */
    withLogLevel(logLevel: LogLevel): ErrorBuilder;
    /**
     * Add alert to error
     * @public
     * @param alert - boolean
     * @returns
     */
    withAlert(alert: boolean): ErrorBuilder;
    /**
     * Add notification to error
     * @public
     * @param notification - {@link ErrorNotification}
     * @returns
     */
    withNotification(notification: ErrorNotification): ErrorBuilder;
    /**
     * Add banner to error
     * @public
     * @param banner - {@link ErrorBanner}
     * @returns
     */
    withBanner(banner: ErrorBanner): ErrorBuilder;
    /**
     * Add snackbar to error
     * @public
     * @param snackbar - {@link Snackbar}
     * @returns
     */
    withSnackbar(snackbar: Snackbar): ErrorBuilder;
    /**
     * Add dialog to error
     * @public
     * @param dialog - {@link ErrorDialog}
     * @returns
     */
    withDialog(dialog: ErrorDialog): ErrorBuilder;
    /**
     * Build ErrorStructure
     * @public
     * @returns
     */
    build(): ErrorStructure;
}
/**
 * Returns a new ErrorBuilder instance
 * @public
 */
export declare const getErrorBuilder: () => ErrorBuilder;
//# sourceMappingURL=error-builder.d.ts.map